@@ -10,35 +10,35 @@
 #' and removing the outdated variables.
 #'
 #' @keywords oTree
-#' @param oTree A list of data frames that were created 
+#' @param oTree A list of data frames that were created
 #' by \code{\link{import_otree}}.
 #' @param combine Logical. \code{TRUE} if all variables referring to
 #' the session code should be merged and/or all variables referring
 #' to participant code should be merged in case data of several versions
 #' of oTree are used.
-#' @param session Logical. \code{TRUE} if all variables referring to the session 
-#' code should be checked and merged. Merging only works 
+#' @param session Logical. \code{TRUE} if all variables referring to the session
+#' code should be checked and merged. Merging only works
 #' if \code{combine = TRUE}.
 #' @param participant Logical. \code{TRUE} if all variables referring to the
-#' participant code should be checked and merged. Merging only works 
+#' participant code should be checked and merged. Merging only works
 #' if \code{combine = TRUE}.
 #' @param info Logical. \code{TRUE} if a brief information on the process should
 #' be printed.
 #' @returns
-#' This function searches for multiple variables related to the session code 
+#' This function searches for multiple variables related to the session code
 #' or the participant code in the \code{$Chats} data frame.
 #' which can occur when data from both old and new oTree versions are used.
-#' 
-#' If \code{combine = FALSE}, the function will throw an error 
+#'
+#' If \code{combine = FALSE}, the function will throw an error
 #' if such variables are found.
-#' 
+#'
 #' If \code{combine = TRUE}, the function will not throw an error
 #' if such variables are found.
-#' Instead, it automatically combines the variables into new variables 
-#' and adds them to the original \code{$Chats} data frame. 
+#' Instead, it automatically combines the variables into new variables
+#' and adds them to the original \code{$Chats} data frame.
 #' This function then returns a duplicate of the original oTree list but
 #' with the \code{$Chats} data frame modified.
-#' 
+#'
 #' The new variables are called
 #' \code{participant_code} and \code{session_code}.
 #' @examplesIf rlang::is_installed("withr")
@@ -58,7 +58,6 @@
 #' # Show all Chats column names again
 #' print(colnames(oTree$Chats))
 
-
 #' @export
 messy_chat <- function(oTree,
                        combine = FALSE,
@@ -75,7 +74,7 @@ messy_chat <- function(oTree,
       c("session_code",
         "participant__session__code") %in% colnames(oTree$Chats))
 
-    if (length_chat_vars > 1 && !combine) {
+    if (length_chat_vars > 1L && !combine) {
         stop_messages <-
           c(stop_messages,
              paste0(
@@ -88,7 +87,7 @@ messy_chat <- function(oTree,
              "You can do this by using the combine-argument in this ",
              "function."))
 
-    } else if (length_chat_vars > 1 && 
+    } else if (length_chat_vars > 1L &&
                combine) {
       oTree$Chats$session_code[is.na(oTree$Chats$session_code)] <-
         oTree$Chats$participant__session__code[is.na(oTree$Chats$session_code)]
@@ -99,7 +98,7 @@ messy_chat <- function(oTree,
         c(warning_messages,
           paste0("More than one variable referred to ",
                  "the session code in ",
-                 "your Chats data frame. You asked for combining them with ",
+                 "your Chats data frame. You asked to combine them with ",
                  "the argument combine = TRUE. ",
                  "Therefore, variable \"participant__session__code\" was ",
                  "integrated into variable ",
@@ -114,7 +113,7 @@ messy_chat <- function(oTree,
       c("participant_code",
         "participant__code") %in% colnames(oTree$Chats))
 
-    if (length_participant_vars > 1 && !combine) {
+    if (length_participant_vars > 1L && !combine) {
         stop_messages <-
           c(stop_messages,
             paste0("More than one variable referred to ",
@@ -127,15 +126,15 @@ messy_chat <- function(oTree,
                     "\"participant__code\". You can do this by using the ",
                     "combine-argument in this ",
                     "function."))
-    } else if (length_participant_vars > 1 && combine) {
+    } else if (length_participant_vars > 1L && combine) {
       oTree$Chats$participant_code[is.na(oTree$Chats$participant_code)] <-
         oTree$Chats$participant__code[is.na(oTree$Chats$participant_code)]
       oTree$Chats$participant__code <- NULL
       warning_messages <-
         c(warning_messages,
         paste0("More than one variable referred to ",
-               "the session code in ",
-               "your Chats data frame. You asked for combining them ",
+               "the participant code in ",
+               "your Chats data frame. You asked to combine them ",
                "with the argument combine = TRUE. ",
                "Therefore, variable \"participant__code\" was integrated ",
                "into variable \"participant_code\"",
@@ -143,11 +142,11 @@ messy_chat <- function(oTree,
     }
   }
 
-  if (length(stop_messages) > 0) {
+  if (length(stop_messages) > 0L) {
     stop(paste(stop_messages, collapse  = "\n"))
   }
 
-  if (info == TRUE && length(warning_messages) > 0) {
+  if (info && length(warning_messages) > 0L) {
     # This is printed as a warning because other functions catch the message
     warning(paste(warning_messages, collapse = "\n"))
   }
